IdentificationMode

Enum IdentificationMode 

#[non_exhaustive]
pub enum IdentificationMode { Conservative, AllGetFunctions, }
Mode to be used for getter identification.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Conservative

Apply conservative rules:

  • The function is a method. This excludes standalone functions or associated functions.
  • The function accepts no arguments besides &['_][mut] self. The methods which accept other arguments are not getters in the sense that they usually don’t return current value of a field and renaming them would harm the semantic. Functions consuming self were also considered not eligible for renaming.
  • The function accepts no type parameter (lifetimes are accepted). The reason is the same as for functions accepting multiple arguments (see above).


AllGetFunctions

Apply name rules to all function with the get prefix.

Implementations